#!/usr/bin/env bash

# files are common to docker and native installation
#____________
# init.conf          => upf config
# startup_debug.conf => vpp config (To Do -> sed location of init.conf file)
# run_sh             => run vpp
#____________

set -euo pipefail

CONFIG_DIR="/openair-upf/etc"

###############################
# UPF Config
###############################

for c in ${CONFIG_DIR}/*.conf; do
    # grep variable names (format: ${VAR}) from template to be rendered
    VARS=$(grep -oP '@[a-zA-Z0-9_]+@' ${c} | sort | uniq | xargs)
    # create sed expressions for substituting each occurrence of ${VAR}
    # with the value of the environment variable "VAR"
    EXPRESSIONS=""
    for v in ${VARS}; do
	NEW_VAR=`echo $v | sed -e "s#@##g"`
        if [[ "${!NEW_VAR}x" == "x" ]]; then
            echo "Error: Environment variable '${NEW_VAR}' is not set." \
                "Config file '$(basename $c)' requires all of $VARS."
            exit 1
        fi
        EXPRESSIONS="${EXPRESSIONS};s|${v}|${!NEW_VAR}|g"
    done
    EXPRESSIONS="${EXPRESSIONS#';'}"
    # render template and inline replace config file
    sed -i "${EXPRESSIONS}" ${c}
done

###############################
# VPP Routes
###############################

# Assumption ->
# UPF has only three interfaces viz. n3 (access) eth0, n4 (core) eth1, n6 (sgi) eth2
# Near future we will have multiple interfaces (e.g. two n6 interface for edge computing case)
# We define in this order in docker-compose -> it is alphabetical order
#
SGI_IPV4=$(ifconfig $INTERFACE_SGI | grep "inet " | awk '{print $2}')

ip link set $INTERFACE_ACCESS down
ip link set $INTERFACE_ACCESS name access
ip link set access up

ip link set $INTERFACE_CORE down
ip link set $INTERFACE_CORE name core
ip link set core up

ip link set $INTERFACE_SGI down
ip link set $INTERFACE_SGI name sgi
ip link set sgi up

ip route add $NETWORK_UE_IP via $SGI_IPV4 dev sgi

echo "Done setting the configuration"

exec "$@"
